# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.9.3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictStr

class V1OrganizationMember(BaseModel):
    """
    V1OrganizationMember
    """
    user: Optional[StrictStr] = None
    user_email: Optional[StrictStr] = None
    role: Optional[StrictStr] = None
    kind: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    __properties = ["user", "user_email", "role", "kind", "created_at", "updated_at"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1OrganizationMember:
        """Create an instance of V1OrganizationMember from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1OrganizationMember:
        """Create an instance of V1OrganizationMember from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1OrganizationMember.parse_obj(obj)

        _obj = V1OrganizationMember.parse_obj({
            "user": obj.get("user"),
            "user_email": obj.get("user_email"),
            "role": obj.get("role"),
            "kind": obj.get("kind"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.9.3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class V1PytorchElasticPolicy(BaseModel):
    """
    V1PytorchElasticPolicy
    """
    min_replicas: Optional[StrictInt] = Field(None, alias="minReplicas", description="minReplicas is the lower limit for the number of replicas to which the training job can scale down.")
    max_replicas: Optional[StrictInt] = Field(None, alias="maxReplicas", description="upper limit for the number of pods that can be set by the autoscaler; cannot be smaller than MinReplicas, defaults to null.")
    rdvz_backend: Optional[StrictStr] = Field(None, alias="rdvzBackend")
    rdvz_port: Optional[StrictInt] = Field(None, alias="rdvzPort")
    rdvz_host: Optional[StrictStr] = Field(None, alias="rdvzHost")
    rdvz_id: Optional[StrictStr] = Field(None, alias="rdvzId")
    rdvz_conf: Optional[conlist(Dict[str, Any])] = Field(None, alias="rdvzConf", description="RDZVConf contains additional rendezvous configuration (<key1>=<value1>,<key2>=<value2>,...).")
    standalone: Optional[StrictBool] = Field(None, description="Start a local standalone rendezvous backend that is represented by a C10d TCP store on port 29400. Useful when launching single-node, multi-worker job. If specified --rdzv_backend, --rdzv_endpoint, --rdzv_id are auto-assigned; any explicitly set values are ignored.")
    n_proc_per_node: Optional[StrictInt] = Field(None, alias="nProcPerNode", description="Number of workers per node; supported values: [auto, cpu, gpu, int]. Deprecated: This API is deprecated in v1.7+ Use .spec.nprocPerNode instead.")
    max_restarts: Optional[StrictInt] = Field(None, alias="maxRestarts")
    metrics: Optional[conlist(Dict[str, Any])] = Field(None, alias="Metrics", description="Metrics contains the specifications which are used to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated with multiplying the ratio between the target value and the current value by the current number of pods. Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the HPA will not be created.")
    __properties = ["minReplicas", "maxReplicas", "rdvzBackend", "rdvzPort", "rdvzHost", "rdvzId", "rdvzConf", "standalone", "nProcPerNode", "maxRestarts", "Metrics"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1PytorchElasticPolicy:
        """Create an instance of V1PytorchElasticPolicy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1PytorchElasticPolicy:
        """Create an instance of V1PytorchElasticPolicy from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1PytorchElasticPolicy.parse_obj(obj)

        _obj = V1PytorchElasticPolicy.parse_obj({
            "min_replicas": obj.get("minReplicas"),
            "max_replicas": obj.get("maxReplicas"),
            "rdvz_backend": obj.get("rdvzBackend"),
            "rdvz_port": obj.get("rdvzPort"),
            "rdvz_host": obj.get("rdvzHost"),
            "rdvz_id": obj.get("rdvzId"),
            "rdvz_conf": obj.get("rdvzConf"),
            "standalone": obj.get("standalone"),
            "n_proc_per_node": obj.get("nProcPerNode"),
            "max_restarts": obj.get("maxRestarts"),
            "metrics": obj.get("Metrics")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.9.3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class V1TruncationStoppingPolicy(BaseModel):
    """
    Early stopping with truncation stopping, this policy stops a percentage of all running runs at every evaluation.
    """
    kind: Optional[StrictStr] = 'truncation'
    percent: Optional[StrictInt] = Field(None, description="The percentage of runs to stop, at each evaluation interval. e.g. 1 - 99.")
    evaluation_interval: Optional[StrictInt] = Field(None, alias="evaluationInterval", description="Interval/Frequency for applying the policy.")
    min_interval: Optional[StrictInt] = Field(None, alias="minInterval")
    min_samples: Optional[StrictInt] = Field(None, alias="minSamples")
    include_succeeded: Optional[StrictBool] = Field(None, alias="includeSucceeded")
    __properties = ["kind", "percent", "evaluationInterval", "minInterval", "minSamples", "includeSucceeded"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1TruncationStoppingPolicy:
        """Create an instance of V1TruncationStoppingPolicy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1TruncationStoppingPolicy:
        """Create an instance of V1TruncationStoppingPolicy from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1TruncationStoppingPolicy.parse_obj(obj)

        _obj = V1TruncationStoppingPolicy.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'truncation',
            "percent": obj.get("percent"),
            "evaluation_interval": obj.get("evaluationInterval"),
            "min_interval": obj.get("minInterval"),
            "min_samples": obj.get("minSamples"),
            "include_succeeded": obj.get("includeSucceeded")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.9.3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from polyaxon_sdk.models.v1_cron_schedule import V1CronSchedule
from polyaxon_sdk.models.v1_date_time_schedule import V1DateTimeSchedule
from polyaxon_sdk.models.v1_interval_schedule import V1IntervalSchedule

class V1Schedule(BaseModel):
    """
    V1Schedule
    """
    cron: Optional[V1CronSchedule] = None
    datetime: Optional[V1DateTimeSchedule] = None
    interval: Optional[V1IntervalSchedule] = None
    __properties = ["cron", "datetime", "interval"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Schedule:
        """Create an instance of V1Schedule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of cron
        if self.cron:
            _dict['cron'] = self.cron.to_dict()
        # override the default output from pydantic by calling `to_dict()` of datetime
        if self.datetime:
            _dict['datetime'] = self.datetime.to_dict()
        # override the default output from pydantic by calling `to_dict()` of interval
        if self.interval:
            _dict['interval'] = self.interval.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Schedule:
        """Create an instance of V1Schedule from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Schedule.parse_obj(obj)

        _obj = V1Schedule.parse_obj({
            "cron": V1CronSchedule.from_dict(obj.get("cron")) if obj.get("cron") is not None else None,
            "datetime": V1DateTimeSchedule.from_dict(obj.get("datetime")) if obj.get("datetime") is not None else None,
            "interval": V1IntervalSchedule.from_dict(obj.get("interval")) if obj.get("interval") is not None else None
        })
        return _obj

